@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.9 $
- * $Date: 1995/11/03 21:18:17 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/gopher/form.c,v $
+ * $Author: jgoerzen $
+ * $Revision: 1.3 $
+ * $Date: 2001/01/17 21:48:05 $
+ * $Source: /var/cvs/gopher/gopher/form.c,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,15 @@
  *********************************************************************
  * Revision History:
  * $Log: form.c,v $
+ * Revision 1.3  2001/01/17 21:48:05  jgoerzen
+ * Many fixes and tune-ups.  Now compiles cleanly with -Wall -Werror!
+ *
+ * Revision 1.2  2001/01/03 22:28:24  s2mdalle
+ * Code cleanups, compiler warning fixes
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.9  1995/11/03  21:18:17  lindner
  * ANSIfication
  *
@@ -150,9 +159,11 @@ FORMfromASK(GopherObj *gs)
      Blockobj *bl;
      char askline[256];
      char *defaultval;
+#if 0
      int i;
      char ** responses = NULL;
      ITEM *item;
+#endif /* 0 */
      FORM *form;
 
      GSgetginfo(gs, TRUE);
@@ -274,6 +285,9 @@ FORMgetAskdata(GopherObj *gs, FORM *form, int Asknum)
 	       case ITEM_PROMPT:
 	       case ITEM_PASSWD:
 		    responses[respnum++] = strdup(ITEMgetResponse(item));
+               case ITEM_UNINIT: /* Unhandled cases... */
+               case ITEM_LABEL:
+               case ITEM_FILENAME:
 	       }
 	  }
 	  responses[respnum++] = NULL;
@@ -295,7 +309,7 @@ FORMaddLabel(FORM *form, char *label)
      ITEMsetType(item, ITEM_LABEL);
      ITEMsetLabel(item, label);
      
-     FORMpush(form, item);
+     FORMpush(form, (char *) item);
 
      ITEMdestroy(item);
 
@@ -320,7 +334,7 @@ FORMaddPrompt(FORM *form, char *prompt, char *defval)
      else 
 	  ITEMsetResponse(item, "");
 
-     FORMpush(form, item);
+     FORMpush(form, (char *)item);
 
      ITEMdestroy(item);
 
@@ -520,8 +534,8 @@ CURform(CursesObj *cur, char *Wintitle, FORM *form)
 			 waddch(tempwin, ' ');
 		    }
 		    wstandend(tempwin);
-	       }
-	  }
+	       } /* End switch */
+	  } /* End for */
 	  
 	  /** Add the labels, centered **/
 	  wmove(tempwin, 3 + numprompts, (COLS-63)/2);
@@ -588,7 +602,7 @@ CURform(CursesObj *cur, char *Wintitle, FORM *form)
 			 waddstr(tempwin, ITEMgetChoiceNum(item,choice));
 			 ITEMsetChoice(item, choice);
 			 wrefresh(tempwin);
-		    }
+		    } /* End while */
 		    wmove(tempwin, 4+numprompts, (COLS-22)/2);
 		    waddstr(tempwin, "                       ");
 		    
@@ -605,7 +619,7 @@ CURform(CursesObj *cur, char *Wintitle, FORM *form)
 				    maxlength, hidden);
 
 		    ITEMsetResponse(item, tmpbuffer);
-	       }
+	       } /* End else */
 
 	       switch (ch) {
 		    
@@ -647,13 +661,11 @@ CURform(CursesObj *cur, char *Wintitle, FORM *form)
 			 thisformdone = TRUE;
 		    }
 		    break;
-	       }
-
-	  }
-
-     }
-
-}
+	       } /* End switch */
+	  } /* End while */
+     } /* End while */
+     return 0;
+} /* End CURform */
 
 
 
