@@ -1,8 +1,8 @@
 /********************************************************************
- * $Author: lindner $
- * $Revision: 3.31 $
- * $Date: 1995/11/03 21:18:20 $
- * $Source: /home/arcwelder/GopherSrc/CVS/gopher+/gopher/manager.c,v $
+ * $Author: s2mdalle $
+ * $Revision: 1.3 $
+ * $Date: 2001/01/03 22:30:43 $
+ * $Source: /var/cvs/gopher/gopher/manager.c,v $
  * $State: Exp $
  *
  * Paul Lindner, University of Minnesota CIS.
@@ -15,6 +15,15 @@
  *********************************************************************
  * Revision History:
  * $Log: manager.c,v $
+ * Revision 1.3  2001/01/03 22:30:43  s2mdalle
+ * Inclusion of new header file for this module.
+ *
+ * Revision 1.2  2000/12/27 21:26:22  s2mdalle
+ * Added #include for CUR* functions
+ *
+ * Revision 1.1.1.1  2000/08/19 00:28:56  jgoerzen
+ * Import from UMN Gopher 2.3.1 after GPLization
+ *
  * Revision 3.31  1995/11/03  21:18:20  lindner
  * ANSIfication
  *
@@ -132,9 +141,11 @@
  *
  *********************************************************************/
 
+#include "CURcurses.h"
 #include "gopher.h"
 #include "patchlevel.h"
 #include "Debug.h"
+#include "manager.h"
 
 #ifdef NOBANNER
 #  define MENULINE(x)   (x)+1
